import torch
import os
from pathlib import Path

# モデルのロード
models = {
    "COCO": torch.hub.load('ultralytics/yolov5', 'custom', path='yolov5s.pt'),
    "Custom": torch.hub.load('ultralytics/yolov5', 'custom', path='boar-civet.pt')
}

# 推論対象フォルダ
source_folder = 'data/images/'  # 処理画像フォルダ
output_dir = 'runs/multi_model_output/'  # 結果保存フォルd

# 画像ファイル取得
image_paths = list(Path(source_folder).glob('*.jpg')) + list(Path(source_folder).glob('*.png'))
if not image_paths:
    print(f"No images found in {source_folder}")
    exit()

# 結果保存先フォルダ作成
os.makedirs(output_dir, exist_ok=True)

# 各モデルで推論
for name, model in models.items():
    print(f"Using model: {name}")
    
    # 各画像を処理
    for image_path in image_paths:
        print(f"Processing {image_path} with model {name}")
        
        # 推論実行
        results = model(str(image_path))
        
        # 保存先ディレクトリを指定
        save_path = Path(output_dir) / name / image_path.name
        results.save(save_dir=str(Path(output_dir) / name))
        print(f"Saved results to {save_path}")
